static const char *recompIcon[] = {
/* columns rows colors chars-per-pixel */
"22 22 193 2",
"   c Gray0",
".  c Transparent",
"X  c #010101",
"o  c Gray1",
"O  c #070707",
"+  c #010801",
"@  c #020900",
"#  c Gray3",
"$  c Gray4",
"%  c #0b0b0b",
"&  c Gray5",
"*  c #041203",
"=  c #061902",
"-  c #121600",
";  c #141400",
":  c #161600",
">  c #101800",
",  c #111113",
"<  c Gray7",
"1  c Gray8",
"2  c #151515",
"3  c Gray9",
"4  c #17171b",
"5  c #191919",
"6  c Gray10",
"7  c Gray11",
"8  c #1d1d1d",
"9  c Gray12",
"0  c #02230b",
"q  c #082003",
"w  c #0b2a05",
"e  c #0d3306",
"r  c #0a3009",
"t  c #112405",
"y  c #142908",
"u  c #142b0a",
"i  c #192c0b",
"p  c #16310c",
"a  c #17320c",
"s  c #1a330d",
"d  c #1b3e0f",
"f  c #113d10",
"g  c #1c3f10",
"h  c #270708",
"j  c #230806",
"k  c #250904",
"l  c #212106",
"z  c #213b14",
"x  c Gray13",
"c  c #222222",
"v  c Gray14",
"b  c #252525",
"n  c Gray16",
"m  c #2a2a2a",
"M  c #2c2c2c",
"N  c Gray18",
"B  c #2f2f2f",
"V  c Gray20",
"C  c #343434",
"Z  c #353535",
"A  c #34343a",
"S  c Gray22",
"D  c Gray23",
"F  c #3c3c3c",
"G  c Gray24",
"H  c #3f3f47",
"J  c #15410c",
"K  c #1c4110",
"L  c #1d4613",
"P  c #1e4917",
"I  c #284919",
"U  c #215017",
"Y  c #225118",
"T  c #275225",
"R  c #2b5623",
"E  c #2d582b",
"W  c #305020",
"Q  c #315c27",
"!  c #217316",
"~  c #25791e",
"^  c #256022",
"/  c #296c27",
"(  c #2a6f2b",
")  c #2a732f",
"_  c #2c7f39",
"`  c #366d2f",
"'  c #337f3a",
"]  c #490f0e",
"[  c #446a3d",
"{  c #417036",
"}  c #407438",
"|  c Gray25",
" . c #414141",
".. c Gray26",
"X. c #434343",
"o. c Gray27",
"O. c #464646",
"+. c Gray28",
"@. c #414149",
"#. c #484848",
"$. c #4b4b4b",
"%. c #4c4c4c",
"&. c Gray30",
"*. c #4a4a52",
"=. c #505050",
"-. c #515151",
";. c #565656",
":. c Gray34",
">. c #52525a",
",. c Gray37",
"<. c #426344",
"1. c #406641",
"2. c #477d40",
"3. c #686868",
"4. c Gray41",
"5. c #6a6a6a",
"6. c #6d6d6d",
"7. c #6f6f6f",
"8. c Gray44",
"9. c #717171",
"0. c Gray46",
"q. c #797979",
"w. c #2c813a",
"e. c #2d823b",
"r. c #2f833c",
"t. c #31843e",
"y. c #32843f",
"u. c #3d8e35",
"i. c #2f8b40",
"p. c #2f8f46",
"a. c #378843",
"s. c #3d8f4b",
"d. c #3a924c",
"f. c #319e52",
"g. c #2fa057",
"h. c #32a65c",
"j. c #32a85d",
"k. c #33b364",
"l. c #34b464",
"z. c #48a92e",
"x. c #49a23f",
"c. c #52aa3f",
"v. c #56ae3b",
"b. c #46914f",
"n. c #419652",
"m. c #50854a",
"M. c #46b670",
"N. c #47b671",
"B. c #55bd7a",
"V. c #668a5f",
"C. c #628663",
"Z. c #63c284",
"A. c #63c385",
"S. c #64c280",
"D. c #65c284",
"F. c #6ac684",
"G. c #6fc386",
"H. c #7dcb8f",
"J. c #c7371a",
"K. c #818181",
"L. c Gray51",
"P. c #848484",
"I. c #898989",
"U. c #8d8d8d",
"Y. c #8f8f97",
"T. c #9a9a9a",
"R. c Gray61",
"E. c Gray63",
"W. c Gray64",
"Q. c #a5a5a5",
"!. c #afafaf",
"~. c #bcbcbc",
"^. c #8ccb84",
"/. c #82cd91",
"(. c #9dc392",
"). c #a3daae",
"_. c #b3d7ac",
"`. c #b0e1b5",
"'. c #b2e0b8",
"]. c #b8e2be",
"[. c #b9e4bd",
"{. c #bee5c1",
"}. c #cacaca",
"|. c #cbe9cb",
" X c #ceecce",
".X c #d4f4d4",
"XX c #d8f0d6",
"oX c #dbf1d9",
"OX c #dff3dd",
"+X c #e0f3dd",
"@X c #e2f4e1",
"#X c #e4f4e1",
"$X c None",
/* pixels */
"$X$X$X$X$X$X$X$XU Y g K z s ; $X$X$X$X$X$X$X",
"$X$X$X$X$X$XL ) D.XX[./.s.2.{ P d $X$X$X$X$X",
"$X$X$X$X$XL j.oX].N.r.L t - l ; P y $X$X$X$X",
"$X$X$X$X$X) @X'.N.m.; ; $X$X$X$X; y > $X$X$X",
"$X$X$X$XL D.|.A.' a $X$X$X$X$X$X$X$Xy ; $X$X",
"$X$X$X$X( #X).y.; $X$X$X$X$X$X$X$X$X$X; $X$X",
"$X$X$X$X/ +XA.b.y $X$X$X$X$X$X$X$X$X$X$X$X$X",
"; d I W g.{.B.y.i ; ; ; $X$X$X$X$X$X$X$X$X$X",
"; _ `.OX.XG.n.a.H. Xw.a $X$X$X. 1 $X$X$X$X$X",
"$X; ` h.l.f.d.S.w.^ ; $X$X$X. E.o.5 $X$X$X$X",
"$X$X; ` p.k.F.w.^ ; $X$X$X. ~.6.P.o.1 $X$X$X",
"$X$X$X; } i.w.^ ; $X$X$X. }.6.S $.U.&.5 $X$X",
"$X$X$X$X; ` ^ ; $X$X$X. ~.8.C c m &.U.o.1 $X",
"$X$X$X$X$X; ; $X$X$XN E.4.o.o.m N N o.8.N % ",
"$X$X$X$X$X$X$X$X$X$X. . . . 0.F =.b . . . . ",
"$X$X$X$X$X$X$X$X$X$X$X$X$X. I. .;.b $X$X$X$X",
"$X$X. $X$X$X$X$X$X$X$X$X$X. E.S =.5 $X$X$X$X",
"$X$X. . $X$X$X$X$X$X$X$X. !.4. . .% $X$X$X$X",
"$X$X$X. . . $X$X$X$X. . !.P. .$.1 $X$X$X$X$X",
"$X$X$X$X% c % 9 . . q.!.K.=.=.N O $X$X$X$X$X",
"$X$X$X$X$X. 9 $.4.K.Q.,. .=.& . $X$X$X$X$X$X",
"$X$X$X$X$X$X$X% , 5 9 c 9 . $X$X$X$X$X$X$X$X"
};

/*
static const char *cleanIcon[] = {
"22 22 9 1",
"  c black",
". c navy",
"X c #800000",
"o c #C00000",
"O c #8080FF",
"+ c #C0C0FF",
"@ c #FFC0C0",
"# c gray100",
"$ c None",
"$$$$$$$$$$$$$$$$+. $$$",
"$$$$$$$$$$$$$$$+OO. $$",
"$$$$$$$$$$$$$$+OOOO. $",
"$$$$$$$$$$$$$+OOOOOO. ",
"$$$$$$$$$$$$+OOOOOOOO.",
"$$$$$$$$$$$+OOOOOOOOO.",
"$$$$$$$$$$+OOOOOOOOO. ",
"$$$$$$$$$+OOOOOOOOO. $",
"$$$$$$$$+OOOOOOOOO. $$",
"$$$$$$$@##OOOOOOO. $$$",
"$$$$$$@oo##OOOOO. $$$$",
"$$$$$@oooo##OOO. $$$$$",
"$$$$@oooooo##O. $$$$$$",
"$$$@oooooooo#. $$$$$$$",
"$$@oooooooooX $$$$$$$$",
"$@oooooooooX $$$$$$$$$",
"@@@oooooooX $$$$$$$$$$",
"@@@@oooooX $$$$$$$$$$$",
"$@@@@oooX $$$$$$$$$$$$",
"$$@@@@oX $$$$$$$$$$$$$",
"$$$@@@X $$$$$$$$$$$$$$",
"$$$$@X $$$$$$$$$$$$$$$"
};
*/

static const char *editIcon[] = {
/* columns rows colors chars-per-pixel */
"22 22 187 2",
"   c Gray0",
".  c #040404",
"X  c #090909",
"o  c Gray5",
"O  c #0e0e0e",
"+  c #101010",
"@  c #151515",
"#  c #161616",
"$  c Gray9",
"%  c #32261e",
"&  c #2e2a22",
"*  c #36322e",
"=  c #363232",
"-  c #422e26",
";  c #524636",
":  c #5a4e36",
">  c #5a4a3e",
",  c #724e3a",
"<  c Gray31",
"1  c #505050",
"2  c #535353",
"3  c #565252",
"4  c Gray33",
"5  c #565656",
"6  c #585858",
"7  c #5b5b5b",
"8  c Gray37",
"9  c #5f5f5f",
"0  c #72664e",
"q  c #776a56",
"w  c #606060",
"e  c #626262",
"r  c Gray39",
"t  c Gray40",
"y  c #686868",
"u  c Gray41",
"i  c Gray42",
"p  c #6d6d6d",
"a  c Gray43",
"s  c #7e766b",
"d  c Gray44",
"f  c Gray45",
"g  c #747474",
"h  c #767676",
"j  c #777777",
"k  c Gray47",
"l  c #7b7b7b",
"z  c Gray",
"x  c #864a1e",
"c  c #9a4606",
"v  c #9e4a06",
"b  c #8e522a",
"n  c #8e5e36",
"m  c #965a3a",
"M  c #92622e",
"N  c #9a6636",
"B  c #a24e06",
"V  c #ae6232",
"C  c #ba7a3e",
"Z  c #877c6e",
"A  c #897960",
"S  c #c25e12",
"D  c #ca6206",
"F  c #ce6602",
"G  c #d66a06",
"H  c #da6e3e",
"J  c #f27e0e",
"K  c #e26a2e",
"L  c #908674",
"P  c #908675",
"I  c #938978",
"U  c #93897a",
"Y  c #998e7f",
"T  c #9d907d",
"R  c #a48f6f",
"E  c #b68a6a",
"W  c #b69e7a",
"Q  c #bc9d70",
"!  c #bd9f74",
"~  c #bda176",
"^  c #bda177",
"/  c #bda27a",
"(  c #bea37b",
")  c #f68606",
"_  c #fa8606",
"`  c #fe8206",
"'  c #fe8602",
"]  c #fe8606",
"[  c #fa820a",
"{  c #fe8a02",
"}  c #fe8a06",
"|  c #fe9632",
" . c #c28246",
".. c #ca825e",
"X. c #da924e",
"o. c #c68662",
"O. c #ce8266",
"+. c #ea8e5a",
"@. c #e29a56",
"#. c #ea9a6e",
"$. c #faae5e",
"%. c #eeb276",
"&. c #808080",
"*. c Gray51",
"=. c #838383",
"-. c #868686",
";. c #9d9382",
":. c #a39882",
">. c #a49985",
",. c #ac9d85",
"<. c #aea28d",
"1. c #afa38e",
"2. c #b2a08a",
"3. c #b2a38b",
"4. c #bea680",
"5. c #b9a688",
"6. c #bfa885",
"7. c #b8a88c",
"8. c #beaa89",
"9. c #bdaa8d",
"0. c #bfab8d",
"q. c #b2a690",
"w. c #b5a593",
"e. c #bbae9c",
"r. c #bcb19c",
"t. c #caae82",
"y. c #c0b29b",
"u. c #c8b79f",
"i. c #d0ba9a",
"p. c #c3b9a6",
"a. c #c4bcac",
"s. c #c3beb0",
"d. c #c5bfb1",
"f. c #f2b296",
"g. c #f6b696",
"h. c #c6c1b6",
"j. c #c9c6bf",
"k. c #d3c1a8",
"l. c #dec6aa",
"z. c #dbcbb1",
"x. c #dacfbd",
"c. c #e2caa2",
"v. c #e0c9ae",
"b. c #e4cca8",
"n. c #e5cda9",
"m. c #e6ceaa",
"M. c #e7cfb3",
"N. c #f6c6aa",
"B. c #fecea6",
"V. c #fed2b2",
"C. c #fedaba",
"Z. c #fedebe",
"A. c #feeaae",
"S. c #cfc9c2",
"D. c Gray79",
"F. c #d3ccc5",
"G. c #d2cec8",
"H. c #d3cfcf",
"J. c Gray82",
"K. c #d3d0d0",
"L. c #d6d6d3",
"P. c #d5d5d5",
"I. c Gray84",
"U. c #efe3d3",
"Y. c #fee2c6",
"T. c #fee6ca",
"R. c #f2eada",
"E. c #fae6d2",
"W. c #feead2",
"Q. c #f2eae2",
"!. c #f6eee2",
"~. c #f4ece4",
"^. c #f7efe7",
"/. c #f5f1e5",
"(. c #f6f2e6",
"). c #f7f3eb",
"_. c #fef2e2",
"`. c #faf2ea",
"'. c #faf6ee",
"]. c #f9f5f1",
"[. c #faf6f6",
"{. c #fafaf6",
"}. c Gray98",
"|. c #fefefa",
" X c Gray99",
".X c #fefefe",
"XX c None",
/* pixels */
"XXXX-.-.=.z k h h d p u t e 9 7 7 2 2   b $.",
"XXXX-.D.D.D.D.D.D.D.D.D.D.D.D.D.D.h.< b $.A.",
"XXXX=.D..X.X.X.X.X.XI..X.X.X.X.X.Xs.b @.A.| ",
"XXXX=.D..X.X.X.X.X.XI..X.X.X.X.X.Xn @.C.| } ",
"XXXXz D..X.X.X.X.X.XI..X.X.X.X.XM @.C.| ` ' ",
"XXXXk D.I.I.I.I.I.I.I.I.I.I.J.N @.B.| ` ' { ",
"XXXXk D..X.X.X.X.X.XI..X.X.XC @.B.| _ ' ) G ",
"XXXXh D..X.X.X.X.X.XI..X.X .X.B.| [ ' ) D B ",
"XXXXd D..X.X.X.X.X.XI..Xg.%.B.| ' ] ) F v o ",
"XXXXd D.I.I.I.I.I.I.I.g.Z.E.#.[ ' ) D v o   ",
"XXXXp D..X.X.X.X.X.XJ.B._.N.+.J [ F c o     ",
"XXXXu D..X.X.X.X.X].g.T.C.#.H K S c o       ",
"XXXXu D..X.X.X|.{.).B.W.g...V b x o $       ",
"XXXXt D.I.I.L.H.G.g.Y.f...m b : o q $       ",
"XXXXe D..X}.{.'.^.V.N.O.m : & * P A $     XX",
"XXXXe D.|.[.`.^.0 E o., > * I T ,.R $   XXXX",
"XXXX9 D.{.'./.t.0 % - 3 I ;.1.y.i.W + XXXXXX",
"XXXX7 D.F.S.j.0 & = t.s P :.3.5.9.( o XXXXXX",
"XXXX7 D./.!.U.; t.Y Z 1.u.z.M.b.c.^ X XXXXXX",
"XXXX5 D.Q.R.U.x.e.w.>.k.v.b.b.c.l.! . XXXXXX",
"XXXX2 h.d.a.p.r.q.3.7.9.8.6.4.( ^ Q   XXXXXX",
"XXXX                                  XXXXXX"
};


static const char *plotIcon[] = {
/* columns rows colors chars-per-pixel */
"22 22 3 1",
"  c Black",
"@ c White",
"- c Gray",
/* pixels */
"                      ",
"    @@@@              ",
"    @  @              ",
"   @    @             ",
"   @    @             ",
"   @    @             ",
"  @      @            ",
"  @      @            ",
"  @      @            ",
" @        @           ",
" @        @           ",
" @        @           ",
"@----------@-------@@@",
"           @       @  ",
"           @       @  ",
"            @     @   ",
"            @     @   ",
"            @     @   ",
"             @   @    ",
"             @   @    ",
"             @@@@@    ",
"                      ",
"                      "
};




static const char *geoIcon[] = {
/* columns rows colors chars-per-pixel */
"22 22 2 1",
"  c Black",
"# c None",
/* pixels */
"                      ",
" ########    ######## ",
" #######      ####### ",
" ######        ###### ",
" #########  ######### ",
" #########  ######### ",
" #########  ######### ",
" ## ######  ###### ## ",
" #  ######  ######  # ",
"    ######  ######    ",
"                      ",
"                      ",
"    ######  ######    ",
" #  ######  ######  # ",
" ## ######  ###### ## ",
" #########  ######### ",
" #########  ######### ",
" #########  ######### ",
" ######        ###### ",
" #######      ####### ",
" ########    ######## ",
"                      "
};




static const char *kspaceIcon[] = {
/* columns rows colors chars-per-pixel */
"22 22 16 1",
"  c black",
". c #111111",
"X c #222222",
"o c gray20",
"O c #444444",
"+ c #555555",
"@ c gray40",
"# c #777777",
"$ c #888888",
"% c gray60",
"& c #aaaaaa",
"* c #bbbbbb",
"= c gray80",
"- c #dddddd",
"; c #eeeeee",
": c None",
/* pixels */
":::::::;*%##::::::::::",
":::::#     #::::::::::",
":::::::O   &::::::::::",
":::::::+   ;::::::::::",
":::::::X  O:::::::::::",
"::::::=   #:::::::::::",
"::::::$   *:::::::::::",
"::::::O  .::::::::::::",
"::::::   +:%X    X::::",
":::::&   $:::X o*:::::",
":::::#   =::& @:::::::",
":::::X  X::*.$::::::::",
"::::-   @:% %:::::::::",
"::::$   %@  ::::::::::",
"::::+   .   *:::::::::",
"::::.   #   $:::::::::",
":::*   #:.  @:::::::::",
":::#   *:+  X:::::::::",
":::o   ::$   -:;+:::::",
":::   +::-   +;O*:::::",
":::   $:::@    #::::::",
":::OOO-:::;O X$:::::::"
};







static const char *simIcon[] = {
/* columns rows colors chars-per-pixel */
"22 22 79 1",
"  c black",
". c #00007F",
"X c #A8A8A7",
"o c #A9A9A7",
"O c #AAAAA8",
"+ c #ACACAA",
"@ c #AFAFAD",
"# c #B0B0AE",
"$ c #B1B1B0",
"% c #B2B2B0",
"& c #B3B3B1",
"* c #B3B3B2",
"= c #B4B4B2",
"- c #B5B5B3",
"; c #B6B6B4",
": c #B6B6B5",
"> c #B7B7B5",
", c #B8B8B6",
"< c #B8B8B7",
"1 c #BABAB8",
"2 c #BBBBB9",
"3 c #BBBBBA",
"4 c #BCBCBB",
"5 c #BDBDBB",
"6 c #BEBEBC",
"7 c #BEBEBD",
"8 c #BFBFBD",
"9 c #BFBFBE",
"0 c #C0C0BF",
"q c #C1C1BF",
"w c #C1C1C0",
"e c #C2C2C0",
"r c #C3C3C2",
"t c #C4C4C2",
"y c #C5C5C4",
"u c #C6C6C5",
"i c #C7C7C5",
"p c #C7C7C6",
"a c #C8C8C7",
"s c #C9C9C8",
"d c #CACAC9",
"f c #CBCBC9",
"g c #CBCBCA",
"h c #CCCCCB",
"j c #CDCDCB",
"k c #CDCDCC",
"l c #CFCFCD",
"z c #D0D0CF",
"x c #D1D1D0",
"c c #D3D3D2",
"v c #D5D5D4",
"b c #D6D6D5",
"n c #D7D7D6",
"m c #D8D8D7",
"M c #DADAD9",
"N c #DBDBDA",
"B c #DDDDDC",
"V c #DEDEDD",
"C c #DFDFDE",
"Z c #E0E0DF",
"A c #E1E1E0",
"S c #E2E2E1",
"D c gray89",
"F c #E5E5E4",
"G c gray90",
"H c #E8E8E7",
"J c #E9E9E9",
"K c #EAEAE9",
"L c #EAEAEA",
"P c #ECECEC",
"I c #EFEFEE",
"U c #EFEFEF",
"Y c gray94",
"T c #F3F3F3",
"R c #F4F4F4",
"E c gray97",
"W c #F9F9F9",
"Q c gray100",
"! c None",
/* pixels */
"!!!!!!!!!!!!!!!!!!!!!!",
"!!!!!!!!!!!!!!!!!!!!!!",
"!!!!!!!!!!!!!!!!!!!!!!",
"!!                 !!!",
"! TTTTTLHD Nvzgp95, !!",
"! RWWRTILF Nv..pr5, !!",
"! RWQWRILF N.zg.95, !!",
"! TRWWTILF B.zg.r5, !!",
"! .TRTIIHD .vlgp.5> !!",
"! .IUILLFZ .vlsp.5> !!",
"! L.LLHFZZ.vzkpr9.& !!",
"!  .      .      .  !!",
"! B.ZZZNNm.zkpr95.* !!",
"! NN.NNmm. gsp95,&. !!",
"! vv.mvvl. sp99<&*. !!",
"! zzz.ll.g p965,*#O !!",
"! sgg.gg.p 965,*#+X !!",
"! pppp..rr 5,>&#+XX !!",
"! rr9rr995 ,>&#+XXX !!",
"!!                 !!!",
"!!!!!!!!!!!!!!!!!!!!!!",
"!!!!!!!!!!!!!!!!!!!!!!"
};




static const char * redIcon[] = {
"18 18 188 2",
"  	c #FFFFFF",
". 	c #C2B6B6",
"+ 	c None",
"@ 	c #523030",
"# 	c #371515",
"$ 	c #331515",
"% 	c #473232",
"& 	c #736868",
"* 	c #BAB7B7",
"= 	c #DBD0D0",
"- 	c #754A4A",
"; 	c #4A0F0F",
"> 	c #490F0F",
", 	c #480F0F",
"' 	c #440F0F",
") 	c #401010",
"! 	c #3A1010",
"~ 	c #331111",
"{ 	c #2B1212",
"] 	c #594D4D",
"^ 	c #D2D1D1",
"/ 	c #CAB5B5",
"( 	c #591212",
"_ 	c #590E0E",
": 	c #5A0D0D",
"< 	c #5A0E0E",
"[ 	c #580E0E",
"} 	c #540E0E",
"| 	c #4F0E0E",
"1 	c #411010",
"2 	c #391010",
"3 	c #2F1111",
"4 	c #281616",
"5 	c #B9B7B7",
"6 	c #DFD0D0",
"7 	c #631111",
"8 	c #660C0C",
"9 	c #690C0C",
"0 	c #6B0C0C",
"a 	c #6A0C0C",
"b 	c #680C0C",
"c 	c #640D0D",
"d 	c #5F0D0D",
"e 	c #500E0E",
"f 	c #460F0F",
"g 	c #3C1010",
"h 	c #311111",
"i 	c #8E4848",
"j 	c #700C0C",
"k 	c #760B0B",
"l 	c #790B0B",
"m 	c #7B0B0B",
"n 	c #780B0B",
"o 	c #740B0B",
"p 	c #6E0C0C",
"q 	c #5D0D0D",
"r 	c #530E0E",
"s 	c #3D1010",
"t 	c #301111",
"u 	c #D3B5B5",
"v 	c #800A0A",
"w 	c #860A0A",
"x 	c #8A0909",
"y 	c #8B0909",
"z 	c #880A0A",
"A 	c #830A0A",
"B 	c #7D0B0B",
"C 	c #600D0D",
"D 	c #3B1010",
"E 	c #2D1111",
"F 	c #AB6363",
"G 	c #8E0909",
"H 	c #950808",
"I 	c #9A0808",
"J 	c #9C0808",
"K 	c #9B0808",
"L 	c #980808",
"M 	c #930909",
"N 	c #820A0A",
"O 	c #770B0B",
"P 	c #510E0E",
"Q 	c #361111",
"R 	c #756868",
"S 	c #972B2B",
"T 	c #A40707",
"U 	c #AA0707",
"V 	c #AC0606",
"W 	c #AC0707",
"X 	c #A80707",
"Y 	c #A10707",
"Z 	c #990808",
"` 	c #4C0F0F",
" .	c #4A3131",
"..	c #940D0D",
"+.	c #9F0808",
"@.	c #B30606",
"#.	c #BA0505",
"$.	c #BD0505",
"%.	c #BC0505",
"&.	c #B70606",
"*.	c #B00606",
"=.	c #A50707",
"-.	c #8D0909",
";.	c #7F0A0A",
">.	c #710C0C",
",.	c #620D0D",
"'.	c #9D0C0C",
").	c #A90707",
"!.	c #B60606",
"~.	c #C10505",
"{.	c #C90404",
"].	c #CD0404",
"^.	c #CC0404",
"/.	c #C60404",
"(.	c #B10606",
"_.	c #960808",
":.	c #870A0A",
"<.	c #3C1414",
"[.	c #AF2828",
"}.	c #B20606",
"|.	c #C00505",
"1.	c #D80303",
"2.	c #DE0202",
"3.	c #DC0202",
"4.	c #D40303",
"5.	c #C80404",
"6.	c #6D0C0C",
"7.	c #4D0F0F",
"8.	c #573030",
"9.	c #C76060",
"0.	c #B80606",
"a.	c #C70404",
"b.	c #D70303",
"c.	c #E50202",
"d.	c #EE0101",
"e.	c #EB0101",
"f.	c #DF0202",
"g.	c #D00303",
"h.	c #910909",
"i.	c #846666",
"j.	c #E5B3B3",
"k.	c #CA0404",
"l.	c #DB0303",
"m.	c #FB0000",
"n.	c #F50000",
"o.	c #C40505",
"p.	c #A30707",
"q.	c #920909",
"r.	c #610D0D",
"s.	c #C5B6B6",
"t.	c #CA4343",
"u.	c #E70202",
"v.	c #F10101",
"w.	c #E10202",
"x.	c #D20303",
"y.	c #C20505",
"z.	c #A20707",
"A.	c #810A0A",
"B.	c #7B4A4A",
"C.	c #F0CECE",
"D.	c #C30909",
"E.	c #AD0606",
"F.	c #9E0808",
"G.	c #7E0A0A",
"H.	c #611111",
"I.	c #DCD0D0",
"J.	c #E9B3B3",
"K.	c #C50808",
"L.	c #D10303",
"M.	c #BF0505",
"N.	c #A60707",
"O.	c #970808",
"P.	c #6C1010",
"Q.	c #CDB5B5",
"R.	c #F1CECE",
"S.	c #CD4343",
"T.	c #BB0505",
"U.	c #8F0909",
"V.	c #964747",
"W.	c #E1D0D0",
"X.	c #E7B3B3",
"Y.	c #CC6060",
"Z.	c #B62828",
"`.	c #A60B0B",
" +	c #9E0C0C",
".+	c #A02A2A",
"++	c #B16262",
"@+	c #D6B4B4",
"+ + + + + . @ @ # $ % & * + + + + + ",
"+ + + = - ; > , ' ) ! ~ { ] ^ + + + ",
"+ + / ( _ : < [ } | > 1 2 3 4 5 + + ",
"+ 6 7 8 9 0 a b c d [ e f g h 4 ^ + ",
"+ i j k l m m n o p 8 q r , s t ] + ",
"u n v w x y y z A B o 0 C } , D E * ",
"F w G H I J K L M y N O 0 d P ' Q R ",
"S M J T U V W X Y Z G N k b : ` s  .",
"..+.U @.#.$.%.&.*.=.I -.;.>.,.r ' # ",
"'.).!.~.{.].^./.$.(.T _.:.n b _ > <.",
"[.}.|.].1.2.3.4.5.#.W J -.B 6.q 7.8.",
"9.0.a.b.c.d.e.f.g.~.(.Y h.v j C | i.",
"j.#.k.l.e.m.n.c.4.o.@.p.q.N >.r.e s.",
"+ t.5.1.u.v.d.w.x.y.}.z.h.A.>.C B.+ ",
"+ C.D.g.l.w.f.b.k.%.E.F.G G.p H.I.+ ",
"+ + J.K.].L.g.{.M.@.N.O.z l P.Q.+ + ",
"+ + + R.S.|.|.T.@.X J U.A.V.W.+ + + ",
"+ + + + + X.Y.Z.`. +.+++@++ + + + + "};


static const char * greenIcon[] = {
"18 18 192 2",
"  	c #FFFFFF",
". 	c #B6C2B9",
"+ 	c None",
"@ 	c #305239",
"# 	c #15371E",
"$ 	c #15331D",
"% 	c #324737",
"& 	c #68736B",
"* 	c #B7BAB7",
"= 	c #D0DBD3",
"- 	c #4A7556",
"; 	c #0F4A1F",
"> 	c #0F491E",
", 	c #0F481E",
"' 	c #0F441D",
") 	c #10401D",
"! 	c #103A1B",
"~ 	c #11331A",
"{ 	c #122B18",
"] 	c #4D5950",
"^ 	c #D1D2D1",
"/ 	c #B5CABB",
"( 	c #125924",
"_ 	c #0E5922",
": 	c #0D5A22",
"< 	c #0E5A22",
"[ 	c #0E5821",
"} 	c #0E5421",
"| 	c #0E4F20",
"1 	c #10411D",
"2 	c #10391B",
"3 	c #112F19",
"4 	c #16281B",
"5 	c #B7B9B7",
"6 	c #D0DFD4",
"7 	c #116326",
"8 	c #0C6624",
"9 	c #0C6925",
"0 	c #0C6B25",
"a 	c #0C6A25",
"b 	c #0C6825",
"c 	c #0D6424",
"d 	c #0D5F23",
"e 	c #0E5020",
"f 	c #0F461E",
"g 	c #103C1C",
"h 	c #11311A",
"i 	c #488E5B",
"j 	c #0C7026",
"k 	c #0B7628",
"l 	c #0B7928",
"m 	c #0B7B29",
"n 	c #0B7828",
"o 	c #0B7427",
"p 	c #0C6E26",
"q 	c #0D5D23",
"r 	c #0E5321",
"s 	c #103D1C",
"t 	c #113019",
"u 	c #B5D3BD",
"v 	c #0A802A",
"w 	c #0A862B",
"x 	c #098A2C",
"y 	c #098B2C",
"z 	c #0A882B",
"A 	c #0A832A",
"B 	c #0B7D29",
"C 	c #0D6023",
"D 	c #103B1B",
"E 	c #112D19",
"F 	c #B7BAB8",
"G 	c #63AB76",
"H 	c #098E2D",
"I 	c #08952E",
"J 	c #089A2F",
"K 	c #089C2F",
"L 	c #089B2F",
"M 	c #08982F",
"N 	c #09932D",
"O 	c #0A822A",
"P 	c #0B7728",
"Q 	c #0E5120",
"R 	c #11361A",
"S 	c #68756B",
"T 	c #2B9747",
"U 	c #07A431",
"V 	c #07AA32",
"W 	c #06AC33",
"X 	c #07AC33",
"Y 	c #07A832",
"Z 	c #07A130",
"` 	c #08992F",
" .	c #0F4C1F",
"..	c #314A38",
"+.	c #0D9430",
"@.	c #089F30",
"#.	c #06B334",
"$.	c #05BA35",
"%.	c #05BD36",
"&.	c #05BC36",
"*.	c #06B735",
"=.	c #06B033",
"-.	c #07A531",
";.	c #098D2C",
">.	c #0A7F29",
",.	c #0C7127",
"'.	c #0D6224",
").	c #0E5320",
"!.	c #0C9D32",
"~.	c #07A932",
"{.	c #06B635",
"].	c #05C137",
"^.	c #04C939",
"/.	c #04CD39",
"(.	c #04CC39",
"_.	c #04C638",
":.	c #06B134",
"<.	c #08962E",
"[.	c #0A872B",
"}.	c #143C1F",
"|.	c #28AF4C",
"1.	c #06B234",
"2.	c #05C037",
"3.	c #03D83C",
"4.	c #02DE3D",
"5.	c #02DC3C",
"6.	c #03D43B",
"7.	c #04C838",
"8.	c #05BA36",
"9.	c #0C6D26",
"0.	c #0F4D1F",
"a.	c #30573A",
"b.	c #60C77C",
"c.	c #06B835",
"d.	c #04C738",
"e.	c #03D73B",
"f.	c #02E53E",
"g.	c #01EE40",
"h.	c #01EB40",
"i.	c #02DF3D",
"j.	c #03D03A",
"k.	c #09912D",
"l.	c #66846E",
"m.	c #B3E5C0",
"n.	c #04CA39",
"o.	c #03DB3C",
"p.	c #00FB43",
"q.	c #00F542",
"r.	c #05C437",
"s.	c #07A331",
"t.	c #09922D",
"u.	c #0D6123",
"v.	c #B6C5BA",
"w.	c #43CA67",
"x.	c #02E73F",
"y.	c #01F141",
"z.	c #02E13D",
"A.	c #03D23A",
"B.	c #05C237",
"C.	c #07A231",
"D.	c #0A812A",
"E.	c #4A7B57",
"F.	c #CEF0D7",
"G.	c #09C33A",
"H.	c #02E13E",
"I.	c #06AD33",
"J.	c #089E30",
"K.	c #0A7E29",
"L.	c #116126",
"M.	c #D0DCD3",
"N.	c #B3E9C1",
"O.	c #08C53B",
"P.	c #03D13A",
"Q.	c #05BF37",
"R.	c #07A631",
"S.	c #08972E",
"T.	c #106C28",
"U.	c #B5CDBB",
"V.	c #CEF1D7",
"W.	c #43CD68",
"X.	c #05BB36",
"Y.	c #098F2D",
"Z.	c #47965C",
"`.	c #D0E1D4",
" +	c #B3E7C1",
".+	c #60CC7D",
"++	c #28B64E",
"@+	c #0BA634",
"#+	c #0C9E32",
"$+	c #2AA049",
"%+	c #62B177",
"&+	c #B4D6BD",
"+ + + + + . @ @ # $ % & * + + + + + ",
"+ + + = - ; > , ' ) ! ~ { ] ^ + + + ",
"+ + / ( _ : < [ } | > 1 2 3 4 5 + + ",
"+ 6 7 8 9 0 a b c d [ e f g h 4 ^ + ",
"+ i j k l m m n o p 8 q r , s t ] + ",
"u n v w x y y z A B o 0 C } , D E F ",
"G w H I J K L M N y O P 0 d Q ' R S ",
"T N K U V W X Y Z ` H O k b :  .s ..",
"+.@.V #.$.%.&.*.=.-.J ;.>.,.'.).' # ",
"!.~.{.].^./.(._.%.:.U <.[.n b _ > }.",
"|.1.2./.3.4.5.6.7.8.X K ;.B 9.q 0.a.",
"b.c.d.e.f.g.h.i.j.].:.Z k.v j C | l.",
"m.$.n.o.h.p.q.f.6.r.#.s.t.O ,.u.e v.",
"+ w.7.3.x.y.g.z.A.B.1.C.k.D.,.C E.+ ",
"+ F.G.j.o.H.i.e.n.&.I.J.H K.p L.M.+ ",
"+ + N.O./.P.j.^.Q.#.R.S.z l T.U.+ + ",
"+ + + V.W.2.2.X.#.Y K Y.D.Z.`.+ + + ",
"+ + + + +  +.+++@+#+$+%+&++ + + + + "};


/*
static const char *recoIcon[] = {
"22 22 178 2",
"   c #000000",
".  c #010101",
"X  c #020202",
"o  c #030303",
"O  c #040404",
"+  c #050505",
"@  c #060606",
"#  c #080808",
"$  c #0A0A0A",
"%  c #0B0B0B",
"&  c #0F0F0F",
"*  c #101010",
"=  c #111111",
"-  c #131313",
";  c #141414",
":  c #151515",
">  c #161616",
",  c #181818",
"<  c #191919",
"1  c #1A1A1A",
"2  c #1B1B1B",
"3  c #1C1C1C",
"4  c #1D1D1D",
"5  c #1E1E1E",
"6  c #1F1F1F",
"7  c #202020",
"8  c #212121",
"9  c #222222",
"0  c #242424",
"q  c #252525",
"w  c #262626",
"e  c #272727",
"r  c #282828",
"t  c #292929",
"y  c #2B2B2B",
"u  c #2C2C2C",
"i  c #2D2D2D",
"p  c #2E2E2E",
"a  c #2F2F2F",
"s  c #303030",
"d  c #313131",
"f  c #323232",
"g  c #333333",
"h  c #363636",
"j  c #373737",
"k  c #393939",
"l  c #3A3A3A",
"z  c #3C3C3C",
"x  c #3D3D3D",
"c  c #3E3E3E",
"v  c #3F3F3F",
"b  c #404040",
"n  c #414141",
"m  c #424242",
"M  c #434343",
"N  c #444444",
"B  c #454545",
"V  c #464646",
"C  c #474747",
"Z  c #484848",
"A  c #494949",
"S  c #4A4A4A",
"D  c #4C4C4C",
"F  c #4D4D4D",
"G  c #4E4E4E",
"H  c #4F4F4F",
"J  c #505050",
"K  c #515151",
"L  c #525252",
"P  c #535353",
"I  c #545454",
"U  c #555555",
"Y  c #575757",
"T  c #585858",
"R  c #595959",
"E  c #5A5A5A",
"W  c #5B5B5B",
"Q  c #5C5C5C",
"!  c #5D5D5D",
"~  c #5F5F5F",
"^  c #606060",
"/  c #616161",
"(  c #626262",
")  c #636363",
"_  c #646464",
"`  c #656565",
"'  c #666666",
"]  c #676767",
"[  c #686868",
"{  c #696969",
"}  c #6A6A6A",
"|  c #6B6B6B",
" . c #6C6C6C",
".. c #6D6D6D",
"X. c #6E6E6E",
"o. c #6F6F6F",
"O. c #707070",
"+. c #717171",
"@. c #727272",
"#. c #737373",
"$. c #747474",
"%. c #767676",
"&. c #777777",
"*. c #787878",
"=. c #797979",
"-. c #7A7A7A",
";. c #7B7B7B",
":. c #7C7C7C",
">. c #7D7D7D",
",. c #7E7E7E",
"<. c #7F7F7F",
"1. c #808080",
"2. c #818181",
"3. c #828282",
"4. c #838383",
"5. c #848484",
"6. c #858585",
"7. c #868686",
"8. c #878787",
"9. c #888888",
"0. c #898989",
"q. c #8A8A8A",
"w. c #8C8C8C",
"e. c #8D8D8D",
"r. c #8F8F8F",
"t. c #909090",
"y. c #929292",
"u. c #939393",
"i. c #959595",
"p. c #969696",
"a. c #979797",
"s. c #989898",
"d. c #999999",
"f. c #9A9A9A",
"g. c #9B9B9B",
"h. c #9C9C9C",
"j. c #9E9E9E",
"k. c #9F9F9F",
"l. c #A2A2A2",
"z. c #A3A3A3",
"x. c #A4A4A4",
"c. c #A5A5A5",
"v. c #A6A6A6",
"b. c #A7A7A7",
"n. c #A8A8A8",
"m. c #A9A9A9",
"M. c #AAAAAA",
"N. c #ABABAB",
"B. c #ACACAC",
"V. c #ADADAD",
"C. c #AEAEAE",
"Z. c #AFAFAF",
"A. c #B0B0B0",
"S. c #B1B1B1",
"D. c #B2B2B2",
"F. c #B4B4B4",
"G. c #B5B5B5",
"H. c #B6B6B6",
"J. c #B7B7B7",
"K. c #BABABA",
"L. c #BBBBBB",
"P. c #BDBDBD",
"I. c #BEBEBE",
"U. c #C1C1C1",
"Y. c #C2C2C2",
"T. c #C3C3C3",
"R. c #C6C6C6",
"E. c #C7C7C7",
"W. c #C8C8C8",
"Q. c #C9C9C9",
"!. c #CECECE",
"~. c #D0D0D0",
"^. c #D1D1D1",
"/. c #DDDDDD",
"(. c #DEDEDE",
"). c #F0F0F0",
"_. c #F4F4F4",
"`. c gray100",

"            O % ; 1 1 ; = O                 ",
"        & e r f f e e f f f 6               ",
"      e l a a a l e 6 e r a n l &           ",
"    j B a C / L B c 8 e 8 f f B C %         ",
"  8 B r E ,.| | U C C l c C L B L C         ",
"O j 6 f O.,.%.%.` L ` Q L E / %.c C =       ",
"; e e B E ..O.2.c.C.F.F.b.%.,.7.a r 8       ",
"e = j ..=.,.r.Y.Y.Y.b.2.W.i.f.7.8 C 6       ",
"e 1 U 2.,.O.R.~.9.F.R.z.f.c.` 8 & ` f O     ",
"6 e O.7.,.E 9.b.P.(.C.f.b.C ; ; c U D C f ; ",
"8 l ,.9.=.=.| O.(._.9.Q ..; r / %.E n E =.B ",
"e l | 2...r.Z.f.~.`.F...j n =.O.%.D B ` D ; ",
"r 8 B ` O.f.Y...c.).i.` 9.=.....L B Q i.=.6 ",
"1 r f L ` f.C.=.C.W.U 7.Z.7.O.C.i.=.,.Q r.L ",
"O n a e D %.2.,.2.j.2.Z.P.W.!.Y.z.F.F.O.2.=.",
"  8 7.O.E n a f n E f.Z.b.F.R.j.r.r.j...r.f ",
"    r ,.c.9.=.7.i.=.` O.,.z.Y.f.f.C.W.%.P.` ",
"      O D J.r.C.9.O.%./ ,.f.F.9.r.Y.W.b.!.O.",
"          Q i.7.=.,.r.Q | | =.9.i.b.P.f.| 1 ",
"          & ,.%.2.=.f./ U E L ,.i./ j 6     ",
"          O E %.Q %.r.O...Q U i.U O         ",
"          O n ` Q | ,.U E =.E =.1           "
};
*/



